@@ -70,7 +70,7 @@ void rbrowndirect(double *coord, double *bounds, int *nObs, int *nSite,
 	
 	/* Compute the Cholesky decomposition of the covariance matrix. */
 	int info = 0;
-	F77_CALL(dpotrf)("U", &neffSite, covmat, &neffSite, &info);
+	F77_CALL(dpotrf)("U", &neffSite, covmat, &neffSite, &info FCONE);
 	
 	if (info != 0)
 	  error("error code %d from Lapack routine '%s'", info, "dpotrf");
@@ -79,7 +79,8 @@ void rbrowndirect(double *coord, double *bounds, int *nObs, int *nSite,
 	for (int j=0; j<neffSite;j++)
 	  gp[j] = norm_rand();
 	
-	F77_CALL(dtrmv)("U", "T", "N", &neffSite, covmat, &neffSite, gp, &oneInt);
+	F77_CALL(dtrmv)("U", "T", "N", &neffSite, covmat, &neffSite, gp, &oneInt
+			FCONE FCONE FCONE);
 	
 	poisson += exp_rand();
 	double ipoisson = -log(poisson), thresh = *uBound + ipoisson;
@@ -102,7 +103,7 @@ void rbrowndirect(double *coord, double *bounds, int *nObs, int *nSite,
     
     /* Compute the Cholesky decomposition of the covariance matrix. */
     int info = 0;
-    F77_CALL(dpotrf)("U", &neffSite, covmat, &neffSite, &info);
+    F77_CALL(dpotrf)("U", &neffSite, covmat, &neffSite, &info FCONE);
     
     if (info != 0)
       error("error code %d from Lapack routine '%s'", info, "dpotrf");
@@ -123,7 +124,8 @@ void rbrowndirect(double *coord, double *bounds, int *nObs, int *nSite,
 	for (int j=0; j<neffSite;j++)
 	  gp[j] = norm_rand();
 	
-	F77_CALL(dtrmv)("U", "T", "N", &neffSite, covmat, &neffSite, gp, &oneInt);
+	F77_CALL(dtrmv)("U", "T", "N", &neffSite, covmat, &neffSite, gp, &oneInt
+			FCONE FCONE FCONE);
 	
 	poisson += exp_rand();
 	double ipoisson = -log(poisson), thresh = *uBound + ipoisson;
@@ -145,7 +147,7 @@ void rbrowndirect(double *coord, double *bounds, int *nObs, int *nSite,
     
     /* Compute the Cholesky decomposition of the covariance matrix. */
     int info = 0;
-    F77_CALL(dpotrf)("U", &neffSite, covmat, &neffSite, &info);
+    F77_CALL(dpotrf)("U", &neffSite, covmat, &neffSite, &info FCONE);
     
     if (info != 0)
       error("error code %d from Lapack routine '%s'", info, "dpotrf");
@@ -166,7 +168,8 @@ void rbrowndirect(double *coord, double *bounds, int *nObs, int *nSite,
 	for (int j=0; j<neffSite;j++)
 	  gp[j] = norm_rand();
 	
-	F77_CALL(dtrmv)("U", "T", "N", &neffSite, covmat, &neffSite, gp, &oneInt);
+	F77_CALL(dtrmv)("U", "T", "N", &neffSite, covmat, &neffSite, gp, &oneInt
+			FCONE FCONE FCONE);
 	
 	poisson += exp_rand();
 	double ipoisson = -log(poisson);
@@ -185,7 +188,7 @@ void rbrowndirect(double *coord, double *bounds, int *nObs, int *nSite,
     
     /* Compute the Cholesky decomposition of the covariance matrix. */
     int info = 0;
-    F77_CALL(dpotrf)("U", &neffSite, covmat, &neffSite, &info);
+    F77_CALL(dpotrf)("U", &neffSite, covmat, &neffSite, &info FCONE);
     
     if (info != 0)
       error("error code %d from Lapack routine '%s'", info, "dpotrf");
@@ -201,7 +204,8 @@ void rbrowndirect(double *coord, double *bounds, int *nObs, int *nSite,
 	for (int j=0; j<neffSite;j++)
 	  gp[j] = norm_rand();
 	
-	F77_CALL(dtrmv)("U", "T", "N", &neffSite, covmat, &neffSite, gp, &oneInt);
+	F77_CALL(dtrmv)("U", "T", "N", &neffSite, covmat, &neffSite, gp, &oneInt
+			FCONE FCONE FCONE);
 
 	// Translation of the process
 	int origIdx = runif(0, neffSite);
@@ -239,7 +243,7 @@ void rbrowndirect(double *coord, double *bounds, int *nObs, int *nSite,
     
     /* Compute the Cholesky decomposition of the covariance matrix. */
     int info = 0;
-    F77_CALL(dpotrf)("U", &neffSite, covmat, &neffSite, &info);
+    F77_CALL(dpotrf)("U", &neffSite, covmat, &neffSite, &info FCONE);
     
     if (info != 0)
       error("error code %d from Lapack routine '%s'", info, "dpotrf");
@@ -272,7 +276,8 @@ void rbrowndirect(double *coord, double *bounds, int *nObs, int *nSite,
 	  for (int j=0; j<neffSite;j++)
 	    gp[j] = norm_rand();
 	
-	  F77_CALL(dtrmv)("U", "T", "N", &neffSite, covmat, &neffSite, gp, &oneInt);
+	  F77_CALL(dtrmv)("U", "T", "N", &neffSite, covmat, &neffSite, gp, &oneInt
+			  FCONE FCONE FCONE);
 
 	  // Translation of the process
 	  double verticalShift = gp[origIdx];
@@ -303,7 +308,7 @@ void rbrowndirect(double *coord, double *bounds, int *nObs, int *nSite,
     
     /* Compute the Cholesky decomposition of the covariance matrix. */
     int info = 0;
-    F77_CALL(dpotrf)("U", &neffSite, covmat, &neffSite, &info);
+    F77_CALL(dpotrf)("U", &neffSite, covmat, &neffSite, &info FCONE);
     
     if (info != 0)
       error("error code %d from Lapack routine '%s'", info, "dpotrf");
@@ -334,7 +339,7 @@ void rbrowndirect(double *coord, double *bounds, int *nObs, int *nSite,
 	  for (int j=0; j<neffSite;j++)
 	    gp[j] = norm_rand();
 	
-	  F77_CALL(dtrmv)("U", "T", "N", &neffSite, covmat, &neffSite, gp, &oneInt);
+	  F77_CALL(dtrmv)("U", "T", "N", &neffSite, covmat, &neffSite, gp, &oneInt FCONE FCONE FCONE);
 
 	  // Translation of the process
 	  double verticalShift = gp[origIdx];
